package models

import (
	"log"
	"time"
)

// deleteOutdatedConsents hard deletes outdated consents where end_date is more than 5 years old
func deleteOutdatedConsents[T GrdfConsent | SgeConsent](dh *DataHandler, model *T, consentType string) {
	log.Printf("Running %v outdated consents cleanup", consentType)
	cutoffDate := time.Now().AddDate(-5, 0, 0)

	result := dh.sqlClient.Unscoped().
		Where("end_date < ?", cutoffDate).
		Delete(model)

	log.Printf("nb of rows %v", result.RowsAffected)

	if result.Error != nil {
		log.Printf("Error deleting outdated %s consents: %v\n", consentType, result.Error)
		return
	}

	if result.RowsAffected > 0 {
		log.Printf("Successfully deleted %d outdated %s consent(s) created before %v\n",
			result.RowsAffected,
			consentType,
			cutoffDate.Format("2006-01-02"))
	}
}

func DeleteOutdatedConsents(dh *DataHandler) {
	deleteOutdatedConsents(dh, &GrdfConsent{}, "GRDF")
	deleteOutdatedConsents(dh, &SgeConsent{}, "SGE")
}
