package models

import (
	"encoding/json"
	"errors"
	"log"
	"net/http"
	"time"

	"forge.grandlyon.com/web-et-numerique/factory/llle_project/backoffice-server/internal/constants"
	"gorm.io/gorm"
)

type CustomPopup struct {
	ID           uint      `gorm:"<-:create"`
	PopupEnabled bool      `json:"popupEnabled"`
	Title        string    `json:"title"`
	Image        string    `json:"image"`
	Description  string    `json:"description"`
	EndDate      time.Time `json:"endDate"`
}

func (dh *DataHandler) GetCustomPopup(w http.ResponseWriter, r *http.Request) {
	var popupInfo CustomPopup
	err := dh.sqlClient.First(&popupInfo).Error

	if errors.Is(err, gorm.ErrRecordNotFound) {
		http.Error(w, "custom popup status not found", http.StatusNotFound)
		return
	}

	w.Header().Set(constants.ContentType, constants.Json)
	json.NewEncoder(w).Encode(popupInfo)
	log.Printf("| get customPopup | %v", r.RemoteAddr)
}

func (dh *DataHandler) SaveCustomPopup(w http.ResponseWriter, r *http.Request) {
	if r.Body == http.NoBody {
		http.Error(w, "request body is empty", http.StatusBadRequest)
		return
	}

	decoder := json.NewDecoder(r.Body)
	var customPopup CustomPopup
	err := decoder.Decode(&customPopup)
	if err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	var updatedCustomPopup CustomPopup

	err = dh.sqlClient.First(&updatedCustomPopup).Error
	if err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	updatedCustomPopup.PopupEnabled = customPopup.PopupEnabled
	updatedCustomPopup.Image = customPopup.Image
	updatedCustomPopup.Title = customPopup.Title
	updatedCustomPopup.Description = customPopup.Description
	updatedCustomPopup.EndDate = customPopup.EndDate

	dh.sqlClient.Save(&updatedCustomPopup)

	w.Header().Set(constants.ContentType, constants.Json)
	json.NewEncoder(w).Encode(customPopup)
	log.Printf("| updated customPopup | %v", r.RemoteAddr)
}
