package models

import (
	"encoding/json"
	"log"
	"net/http"

	"forge.grandlyon.com/web-et-numerique/factory/llle_project/backoffice-server/internal/common"
	"forge.grandlyon.com/web-et-numerique/factory/llle_project/backoffice-server/internal/constants"
)

type MonthlyInfo struct {
	Year  int    `json:"year"`
	Month int    `json:"month"`
	Info  string `json:"info"`
	Image string `json:"image"`
}

func (dh *DataHandler) GetAllMonthlyInfo(w http.ResponseWriter, r *http.Request) {
	var monthlyInfo []MonthlyInfo
	dh.sqlClient.Find(&monthlyInfo)

	w.Header().Set(constants.ContentType, constants.Json)
	json.NewEncoder(w).Encode(monthlyInfo)
	log.Printf("| get all monthlyInfo | %v", r.RemoteAddr)
}

func (dh *DataHandler) GetSingleMonthlyInfo(w http.ResponseWriter, r *http.Request) {
	year, month, err := common.YearMonthFromRequest(r)
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	w.Header().Set(constants.ContentType, constants.Json)

	var monthlyInfo MonthlyInfo
	err = dh.sqlClient.Where("year = ? AND month = ?", year, month).First(&monthlyInfo).Error
	if err != nil {
		// If not found, answer "not found"
		w.WriteHeader(http.StatusNotFound)
		return
	}
	json.NewEncoder(w).Encode(monthlyInfo)
}

func (dh *DataHandler) SaveMonthlyInfo(w http.ResponseWriter, r *http.Request) {
	if r.Body == http.NoBody {
		http.Error(w, "request body is empty", http.StatusBadRequest)
		return
	}

	decoder := json.NewDecoder(r.Body)
	var monthlyInfo MonthlyInfo
	err := decoder.Decode(&monthlyInfo)
	if err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	// Check if this monthlyInfo exists
	err = dh.sqlClient.Where("year = ? AND month = ?", monthlyInfo.Year, monthlyInfo.Month).First(&MonthlyInfo{}).Error

	if err != nil {
		// Create a monthlyInfo
		err = dh.sqlClient.Create(&MonthlyInfo{
			Year:  monthlyInfo.Year,
			Month: monthlyInfo.Month,
			Info:  monthlyInfo.Info,
			Image: monthlyInfo.Image,
		}).Error
		if err != nil {
			w.WriteHeader(http.StatusInternalServerError)
			return
		}
		w.WriteHeader(http.StatusCreated)
		json.NewEncoder(w).Encode(monthlyInfo)

		log.Printf("| new monthlyInfo | year : %d month : %d | %v", monthlyInfo.Year, monthlyInfo.Month, r.RemoteAddr)
		return

	} else {
		// Update info
		err = dh.sqlClient.Model(&MonthlyInfo{}).Where("year = ? AND month = ?", monthlyInfo.Year, monthlyInfo.Month).Update("info", monthlyInfo.Info).Error
		if err != nil {
			w.WriteHeader(http.StatusInternalServerError)
			return
		}

		// Update info
		err = dh.sqlClient.Model(&MonthlyInfo{}).Where("year = ? AND month = ?", monthlyInfo.Year, monthlyInfo.Month).Update("image", monthlyInfo.Image).Error
		if err != nil {
			w.WriteHeader(http.StatusInternalServerError)
			return
		}

		json.NewEncoder(w).Encode(monthlyInfo)
		log.Printf("| updated monthlyInfo | year : %d month : %d | %v", monthlyInfo.Year, monthlyInfo.Month, r.RemoteAddr)
	}
}

func (dh *DataHandler) DeleteMonthlyInfo(w http.ResponseWriter, r *http.Request) {
	year, month, err := common.YearMonthFromRequest(r)
	if err != nil {
		http.Error(w, err.Error(), http.StatusBadRequest)
		return
	}

	err = dh.sqlClient.Where("year = ? AND month = ?", year, month).Delete(&MonthlyInfo{}).Error
	if err != nil {
		http.Error(w, err.Error(), http.StatusNotFound)
		return
	}

	w.WriteHeader(http.StatusOK)
	w.Write([]byte("successful delete"))
}
