package models

import (
	"encoding/json"
	"errors"
	"log"
	"net/http"

	"forge.grandlyon.com/web-et-numerique/factory/llle_project/backoffice-server/internal/constants"
	"gorm.io/gorm"
)

type PartnersInfo struct {
	ID                    uint `gorm:"<-:create"`
	GRDFFailure           bool `json:"grdf_failure"`
	EnedisFailure         bool `json:"enedis_failure"`
	EGLFailure            bool `json:"egl_failure"`
	NotificationActivated bool `json:"notification_activated"`
}

func (dh *DataHandler) GetPartnersInfo(w http.ResponseWriter, r *http.Request) {
	var partnersInfo PartnersInfo
	err := dh.sqlClient.First(&partnersInfo).Error

	if errors.Is(err, gorm.ErrRecordNotFound) {
		http.Error(w, "partners status not found", http.StatusNotFound)
		return
	}

	w.Header().Set(constants.ContentType, constants.Json)
	json.NewEncoder(w).Encode(partnersInfo)
	log.Printf("| get partnersInfo | %v", r.RemoteAddr)
}

func (dh *DataHandler) SavePartnersInfo(w http.ResponseWriter, r *http.Request) {
	if r.Body == http.NoBody {
		http.Error(w, "request body is empty", http.StatusBadRequest)
		return
	}

	decoder := json.NewDecoder(r.Body)
	var partnersInfo PartnersInfo
	err := decoder.Decode(&partnersInfo)
	if err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	var updatedPartnersInfo PartnersInfo

	err = dh.sqlClient.First(&updatedPartnersInfo).Error
	if err != nil {
		w.WriteHeader(http.StatusInternalServerError)
		return
	}

	updatedPartnersInfo.GRDFFailure = partnersInfo.GRDFFailure
	updatedPartnersInfo.EnedisFailure = partnersInfo.EnedisFailure
	updatedPartnersInfo.EGLFailure = partnersInfo.EGLFailure
	updatedPartnersInfo.NotificationActivated = partnersInfo.NotificationActivated

	dh.sqlClient.Save(&updatedPartnersInfo)

	w.Header().Set(constants.ContentType, constants.Json)
	json.NewEncoder(w).Encode(partnersInfo)
	log.Printf("| updated partnersInfo | %v", r.RemoteAddr)
}
